==> spip_2.0.10.orig.tar.gz: spip-2.0.10.orig/ecrire/lang/public_cpf.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Lakey lo sit',
'articles' => 'Bann zartik',
'articles_auteur' => 'Bann zartik lot&egrave;r-la',
'articles_populaires' => 'Bann zartik sak l&eacute; pli popil&egrave;r',
'articles_rubrique' => 'Bann zartik andann ribrik-la',
'aucun_article' => 'N&eacute;na pa okinn lartik si ladr&egrave;s-la',
'aucun_auteur' => 'N&eacute;na pa okinn lot&egrave;r si ladr&egrave;s-la',
'aucun_site' => 'N&eacute;na pa okin sitw&egrave;b si ladr&egrave;s-la',
'aucune_breve' => 'N&eacute;na pa okin titnouv&egrave;l si ladr&egrave;s-la',
'aucune_rubrique' => 'N&eacute;na pa okinn ribrik si ladr&egrave;s-la',
'autres_breves' => 'Bann zot tite-nouv&egrave;l',
'autres_groupes_mots_clefs' => 'Bann zot bann molakl&eacute;',
'autres_sites' => 'Bann zot sitw&egrave;b',

// B
'bonjour' => 'Ot&eacute;',
'breves' => 'Bann tite-nouv&egrave;l',

// C
'commenter_site' => 'Donn out lavi si lo sit-la',

// D
'date' => 'Ladat',
'dernier_ajout' => 'Derny&eacute; piblikasyon',
'dernieres_breves' => 'Bann derniy&egrave;r tit-nouv&egrave;l',
'derniers_articles' => 'Bann d&egrave;rny&eacute; zartik',
'derniers_commentaires' => 'Bann d&egrave;rny&eacute; lavi',
'derniers_messages_forum' => 'Bann d&egrave;rny&eacute; mod&eacute;kri andann bann forom',

// E
'edition_mode_texte' => 'Po &eacute;dit&eacute; andann mod t&egrave;ks',
'en_reponse' => 'Po r&eacute;ponn a&nbsp;:',
'en_resume' => 'Po r&eacute;zim&eacute;',
'envoyer_message' => 'Po anvway&eacute; inn mod&eacute;kri',
'espace_prive' => 'L&eacute;spas priv&eacute;',

// F
'forum' => 'Forom kozman',

// H
'hierarchie_site' => 'Bardrin lo sitw&egrave;b',

// J
'jours' => 'bann zour',

// M
'meme_auteur' => 'Pa lot&egrave;r minm sa-minm',
'meme_rubrique' => 'Andan minm ribrik-la',
'memes_auteurs' => 'Po bann zot&egrave;r minm',
'message' => 'Mod&eacute;kri',
'messages_forum' => 'Bann mod&eacute;kri andann forom',
'messages_recents' => 'Bann mod&eacute;kri la finn m&egrave;t an derny&eacute; andan forom',
'mots_clefs' => 'Bann molakl&eacute;',
'mots_clefs_meme_groupe' => 'Bann molakl&eacute; andann lo minm bann sa-minm',

// N
'navigation' => 'Bat-kar&eacute; si lo sit',
'nom' => 'Non',
'nouveautes' => 'Bann nouv&egrave;lt&eacute;',
'nouveautes_web' => 'Bann nouv&egrave;lt&eacute; si lo sitw&egrave;b',
'nouveaux_articles' => 'Bann nouvo lartik',
'nouvelles_breves' => 'Bann nouv&egrave;l tite-nouv&egrave;l',

// P
'page_precedente' => 'lapaz dovan',
'page_suivante' => 'Lapaz d&eacute;y&egrave;r',
'par_auteur' => 'sanm',
'participer_site' => 'Ou p&eacute; m&egrave;t ansanm bann zot dalon po la vi lo sit-la, &egrave; propoz&eacute; out prop bann zartik, si ou l&eacute; inskri anba-la. Inskri aou : ou sar gayn inn lim&egrave;l i don aou out bann kodlaks&eacute; po l&eacute;spas priv&eacute; lo sit. ',
'plan_site' => 'Lakart lo sit',
'popularite' => 'Koman l&eacute; popil&egrave;r',
'poster_message' => 'Anvwa in mod&eacute;kri',
'proposer_site' => 'Ou p&eacute; propoz azout inn sit dann ribrik-la&nbsp;:',

// R
'repondre_article' => 'Po r&eacute;ponn si lartik-la',
'repondre_breve' => 'Po r&eacute;ponn la tite-nouv&egrave;l-la',
'repondre_message' => 'Po r&eacute;ponn mod&eacute;kri-la',
'resultats_recherche' => 'Kosa lo rod&egrave;r la finn trouv&eacute;',
'retour_debut_forums' => 'Artourn bann d&eacute;bi bann forom',
'rubrique' => 'Ribrik',
'rubriques' => 'Bann ribrik',

// S
'signatures_petition' => 'Bann sinyatir',
'site_realise_avec_spip' => 'Sit-la ni la f&eacute; &egrave;k SPIP',
'sites_web' => 'Bann sitw&egrave;b',
'sous_rubriques' => 'Bann souribrik',
'suite' => 'laswit',
'sur_web' => 'Si lo w&egrave;b',
'syndiquer_rubrique' => 'Po sindik&eacute; ribrik-la',
'syndiquer_site' => 'Po sindik&eacute; si lo sit',

// T
'texte_lettre_information' => 'Ala lal&egrave;t zinformasyon lo sit',
'texte_lettre_information_2' => 'L&egrave;t-la i ramas tout bann zartik &egrave;k bann tite-nouv&egrave;l dopwi',

// V
'ver_imprimer' => 'V&egrave;rsyon pou inprim&eacute;',
'voir_en_ligne' => 'Anon vwar an liyn',
'voir_squelette' => 'Apiy po t&eacute;l&eacute;sarz l&eacute;sk&eacute;let lapaz-la'
);

?>

==> spip_2.1.1.orig.tar.gz: spip-2.1.1/ecrire/lang/public_cpf.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Lakey lo sit',
'article' => 'Article', # NEW
'articles' => 'Bann zartik',
'articles_auteur' => 'Bann zartik lot&egrave;r-la',
'articles_populaires' => 'Bann zartik sak l&eacute; pli popil&egrave;r',
'articles_rubrique' => 'Bann zartik andann ribrik-la',
'aucun_article' => 'N&eacute;na pa okinn lartik si ladr&egrave;s-la',
'aucun_auteur' => 'N&eacute;na pa okinn lot&egrave;r si ladr&egrave;s-la',
'aucun_site' => 'N&eacute;na pa okin sitw&egrave;b si ladr&egrave;s-la',
'aucune_breve' => 'N&eacute;na pa okin titnouv&egrave;l si ladr&egrave;s-la',
'aucune_rubrique' => 'N&eacute;na pa okinn ribrik si ladr&egrave;s-la',
'auteur' => 'Auteur', # NEW
'autres' => 'Autres', # NEW
'autres_breves' => 'Bann zot tite-nouv&egrave;l',
'autres_groupes_mots_clefs' => 'Bann zot bann molakl&eacute;',
'autres_sites' => 'Bann zot sitw&egrave;b',

// B
'bonjour' => 'Ot&eacute;',
'breve' => 'Br&egrave;ve', # NEW
'breves' => 'Bann tite-nouv&egrave;l',

// C
'commenter_site' => 'Donn out lavi si lo sit-la',
'copie_document_impossible' => 'Impossible de copier le document', # NEW

// D
'date' => 'Ladat',
'dernier_ajout' => 'Derny&eacute; piblikasyon',
'dernieres_breves' => 'Bann derniy&egrave;r tit-nouv&egrave;l',
'derniers_articles' => 'Bann d&egrave;rny&eacute; zartik',
'derniers_commentaires' => 'Bann d&egrave;rny&eacute; lavi',
'derniers_messages_forum' => 'Bann d&egrave;rny&eacute; mod&eacute;kri andann bann forom',
'documents_interdits_forum' => 'Documents interdits dans le forum', # NEW

// E
'edition_mode_texte' => 'Po &eacute;dit&eacute; andann mod t&egrave;ks',
'en_reponse' => 'Po r&eacute;ponn a&nbsp;:',
'en_resume' => 'Po r&eacute;zim&eacute;',
'envoyer_message' => 'Po anvway&eacute; inn mod&eacute;kri',
'espace_prive' => 'L&eacute;spas priv&eacute;',

// F
'formats_acceptes' => 'Formats accept&#233;s : @formats@.', # NEW
'forum' => 'Forom kozman',

// H
'hierarchie_site' => 'Bardrin lo sitw&egrave;b',

// J
'jours' => 'bann zour',

// L
'lien_connecter' => 'Se connecter', # NEW

// M
'meme_auteur' => 'Pa lot&egrave;r minm sa-minm',
'meme_rubrique' => 'Andan minm ribrik-la',
'memes_auteurs' => 'Po bann zot&egrave;r minm',
'message' => 'Mod&eacute;kri',
'messages_forum' => 'Bann mod&eacute;kri andann forom',
'messages_recents' => 'Bann mod&eacute;kri la finn m&egrave;t an derny&eacute; andan forom',
'mots_clef' => 'Mot-cl&eacute;', # NEW
'mots_clefs' => 'Bann molakl&eacute;',
'mots_clefs_meme_groupe' => 'Bann molakl&eacute; andann lo minm bann sa-minm',

// N
'navigation' => 'Bat-kar&eacute; si lo sit',
'nom' => 'Non',
'nouveautes' => 'Bann nouv&egrave;lt&eacute;',
'nouveautes_web' => 'Bann nouv&egrave;lt&eacute; si lo sitw&egrave;b',
'nouveaux_articles' => 'Bann nouvo lartik',
'nouvelles_breves' => 'Bann nouv&egrave;l tite-nouv&egrave;l',

// P
'page_precedente' => 'lapaz dovan',
'page_suivante' => 'Lapaz d&eacute;y&egrave;r',
'par_auteur' => 'sanm',
'participer_site' => 'Ou p&eacute; m&egrave;t ansanm bann zot dalon po la vi lo sit-la, &egrave; propoz&eacute; out prop bann zartik, si ou l&eacute; inskri anba-la. Inskri aou : ou sar gayn inn lim&egrave;l i don aou out bann kodlaks&eacute; po l&eacute;spas priv&eacute; lo sit. ',
'plan_site' => 'Lakart lo sit',
'popularite' => 'Koman l&eacute; popil&egrave;r',
'poster_message' => 'Anvwa in mod&eacute;kri',
'proposer_site' => 'Ou p&eacute; propoz azout inn sit dann ribrik-la&nbsp;:',

// R
'repondre_article' => 'Po r&eacute;ponn si lartik-la',
'repondre_breve' => 'Po r&eacute;ponn la tite-nouv&egrave;l-la',
'repondre_message' => 'Po r&eacute;ponn mod&eacute;kri-la',
'resultats_recherche' => 'Kosa lo rod&egrave;r la finn trouv&eacute;',
'retour_debut_forums' => 'Artourn bann d&eacute;bi bann forom',
'rubrique' => 'Ribrik',
'rubriques' => 'Bann ribrik',

// S
'signatures_petition' => 'Bann sinyatir',
'site_realise_avec_spip' => 'Sit-la ni la f&eacute; &egrave;k SPIP',
'sites_web' => 'Bann sitw&egrave;b',
'sous_rubriques' => 'Bann souribrik',
'spam' => 'Spam', # NEW
'suite' => 'laswit',
'sur_web' => 'Si lo w&egrave;b',
'syndiquer_rubrique' => 'Po sindik&eacute; ribrik-la',
'syndiquer_site' => 'Po sindik&eacute; si lo sit',

// T
'texte_lettre_information' => 'Ala lal&egrave;t zinformasyon lo sit',
'texte_lettre_information_2' => 'L&egrave;t-la i ramas tout bann zartik &egrave;k bann tite-nouv&egrave;l dopwi',

// V
'ver_imprimer' => 'V&egrave;rsyon pou inprim&eacute;',
'voir_en_ligne' => 'Anon vwar an liyn',
'voir_squelette' => 'Apiy po t&eacute;l&eacute;sarz l&eacute;sk&eacute;let lapaz-la'
);

?>
